==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translation>Kyselyikkuna</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translation>Kaaret ja ympyrät</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translation>viivan segmentteihin (kiinteä pituus)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translation>viivan segmentteihin (kiinteä kulma)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translation>Ellipsit</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translation>monilinjaan kaarisegmenteillä</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translation>monilinjaan viivasegmenteillä</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translation>Käyrät</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translation>Mitat</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translation>viivoihin, kiinteisiin ja teksteihin</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translation>Luukut</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translation>viivoihin</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translation>Lohkot</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translation>kohteisiin</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>Räjäytä</translation>
    </message>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translation>&amp;Räjäytä</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+133"/>
        <source>Spline segments:</source>
        <translation>Käyrän segmentit:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>Ellipsin segmentit (koko ellipsissä):</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Spline approximation tolerance:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Explode/ts/Explode_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../ExplodeDialog.ui" line="+14"/>
        <source>Dialog</source>
        <translation>Kyselyikkuna</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Arcs and Circles</source>
        <translation>Kaaret ja ympyrät</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into line segments (fixed length)</source>
        <translation>viivan segmentteihin (kiinteä pituus)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>into line segments (fixed angle)</source>
        <translation>viivan segmentteihin (kiinteä kulma)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ellipses</source>
        <translation>Ellipsit</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into polyline with arc segments</source>
        <translation>monilinjaan kaarisegmenteillä</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+16"/>
        <source>into polyline with line segments</source>
        <translation>monilinjaan viivasegmenteillä</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Splines</source>
        <translation>Käyrät</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Dimensions</source>
        <translation>Mitat</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines, solids and texts</source>
        <translation>viivoihin, kiinteisiin ja teksteihin</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Hatches</source>
        <translation>Luukut</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into lines</source>
        <translation>viivoihin</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Blocks</source>
        <translation>Lohkot</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>into entities</source>
        <translation>kohteisiin</translation>
    </message>
</context>
<context>
    <name>Explode</name>
    <message>
        <location filename="../Explode.js" line="+30"/>
        <source>Modify</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Explode</source>
        <translation>Räjäytä</translation>
    </message>
    <message>
        <location filename="../ExplodeInit.js" line="+2"/>
        <source>&amp;Explode</source>
        <translation>&amp;Räjäytä</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+197"/>
        <source>Explode text glyphs to polylines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Spline segments:</source>
        <translation>Käyrän segmentit:</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>Ellipse segments (per full ellipse):</source>
        <translation>Ellipsin segmentit (koko ellipsissä):</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Explode splines to polylines with line segments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Explode multiline texts into multiple simple text blocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-31"/>
        <source>Spline approximation tolerance:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
